pub fn quat_axis<T>(
x: &Quaternion<T>,
) -> Matrix<T, Const<3>, Const<1>, ArrayStorage<T, 3, 1>>where
T: RealNumber,Expand description
The rotation axis of a quaternion assumed to be normalized.
pub fn quat_axis<T>(
x: &Quaternion<T>,
) -> Matrix<T, Const<3>, Const<1>, ArrayStorage<T, 3, 1>>where
T: RealNumber,The rotation axis of a quaternion assumed to be normalized.